@@ -39,10 +39,21 @@ our @EXPORT_OK = qw(
     ouroboros_sv_rok_ptr
     ouroboros_sv_rv_ptr
     ouroboros_sv_type_ptr
+    ouroboros_sv_flags_ptr
+    ouroboros_sv_utf8_ptr
+    ouroboros_sv_utf8_on_ptr
+    ouroboros_sv_utf8_off_ptr
     ouroboros_gv_sv_ptr
     ouroboros_gv_av_ptr
     ouroboros_gv_hv_ptr
     ouroboros_gv_cv_ptr
+    ouroboros_he_pv_ptr
+    ouroboros_he_val_ptr
+    ouroboros_he_hash_ptr
+    ouroboros_he_svkey_ptr
+    ouroboros_he_svkey_force_ptr
+    ouroboros_he_svkey_set_ptr
+    ouroboros_perl_hash_ptr
     ouroboros_sv_refcnt_ptr
     ouroboros_sv_refcnt_inc_ptr
     ouroboros_sv_refcnt_inc_nn_ptr
@@ -69,7 +80,7 @@ our %EXPORT_TAGS = (
 
 our @EXPORT = qw();
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 require XSLoader;
 XSLoader::load('Ouroboros', $VERSION);
@@ -324,6 +335,30 @@ Perl macro: C<SvRV>
 
 Perl macro: C<SvTYPE>
 
+=item ouroboros_sv_flags_ptr
+
+    UV ouroboros_sv_flags(pTHX_ SV*);
+
+Perl macro: C<SvFLAGS>
+
+=item ouroboros_sv_utf8_ptr
+
+    bool ouroboros_sv_utf8(pTHX_ SV*);
+
+Perl macro: C<SvUTF8>
+
+=item ouroboros_sv_utf8_on_ptr
+
+    void ouroboros_sv_utf8_on(pTHX_ SV*);
+
+Perl macro: C<SvUTF8_on>
+
+=item ouroboros_sv_utf8_off_ptr
+
+    void ouroboros_sv_utf8_off(pTHX_ SV*);
+
+Perl macro: C<SvUTF8_off>
+
 =item ouroboros_gv_sv_ptr
 
     SV* ouroboros_gv_sv(pTHX_ GV*);
@@ -348,6 +383,50 @@ Perl macro: C<GvHV>
 
 Perl macro: C<GvCV>
 
+=item ouroboros_he_pv_ptr
+
+    const char* ouroboros_he_pv(pTHX_ HE*, STRLEN*);
+
+Perl macro: C<HePV>
+
+=item ouroboros_he_val_ptr
+
+    SV* ouroboros_he_val(pTHX_ HE*);
+
+Perl macro: C<HeVAL>
+
+=item ouroboros_he_hash_ptr
+
+    U32 ouroboros_he_hash(pTHX_ HE*);
+
+Perl macro: C<HeHASH>
+
+=item ouroboros_he_svkey_ptr
+
+    SV* ouroboros_he_svkey(pTHX_ HE*);
+
+Perl macro: C<HeSVKEY>
+
+=item ouroboros_he_svkey_force_ptr
+
+    SV* ouroboros_he_svkey_force(pTHX_ HE*);
+
+Perl macro: C<HeSVKEY_force>
+
+=item ouroboros_he_svkey_set_ptr
+
+    SV* ouroboros_he_svkey_set(pTHX_ HE*, SV*);
+
+Perl macro: C<HeSVKEY_set>
+
+=item ouroboros_perl_hash_ptr
+
+    U32 ouroboros_perl_hash(pTHX_ U8*, STRLEN);
+
+Unlike macro, returns hash value instead of assigning it to an argument.
+
+Perl macro: C<PERL_HASH>
+
 =item ouroboros_sv_refcnt_ptr
 
     U32 ouroboros_sv_refcnt(pTHX_ SV*);
