@@ -2,6 +2,7 @@
 #define OUROBOROS_H
 
 #define PERL_NO_GET_CONTEXT
+#define NO_XSLOCKS
 #include "EXTERN.h"
 #include "perl.h"
 #include "XSUB.h"
@@ -45,10 +46,21 @@ const char* ouroboros_sv_pv_nolen(pTHX_ SV*);
 U32 ouroboros_sv_rok(pTHX_ SV*);
 SV* ouroboros_sv_rv(pTHX_ SV*);
 IV ouroboros_sv_type(pTHX_ SV*);
+UV ouroboros_sv_flags(pTHX_ SV*);
+bool ouroboros_sv_utf8(pTHX_ SV*);
+void ouroboros_sv_utf8_on(pTHX_ SV*);
+void ouroboros_sv_utf8_off(pTHX_ SV*);
 SV* ouroboros_gv_sv(pTHX_ GV*);
 AV* ouroboros_gv_av(pTHX_ GV*);
 HV* ouroboros_gv_hv(pTHX_ GV*);
 CV* ouroboros_gv_cv(pTHX_ CV*);
+const char* ouroboros_he_pv(pTHX_ HE*, STRLEN*);
+SV* ouroboros_he_val(pTHX_ HE*);
+U32 ouroboros_he_hash(pTHX_ HE*);
+SV* ouroboros_he_svkey(pTHX_ HE*);
+SV* ouroboros_he_svkey_force(pTHX_ HE*);
+SV* ouroboros_he_svkey_set(pTHX_ HE*, SV*);
+U32 ouroboros_perl_hash(pTHX_ U8*, STRLEN);
 U32 ouroboros_sv_refcnt(pTHX_ SV*);
 SV* ouroboros_sv_refcnt_inc(pTHX_ SV*);
 SV* ouroboros_sv_refcnt_inc_nn(pTHX_ SV*);
